function [ b ] = clenshaw_curtis_type_coeffs(f,N,m,c)    %f0r m=2 also add 'df'. 
% the coefficients Clenshaw-Curtis-type quadrature rule
% Hermite interpolation: P(x_j) = f(x_j); P^{(k)}(c) = f^{(k)}(c),k=0,...,m-1
% N: Clenshaw-Curtis points: x_j = cos(j\pi/N)
% m: degree of derivatives
% c: inter point

b = zeros(1,N+m);
P = chebfun(f,N);
dP = diff(P);
a = chebcoeffs(P); b(1:N) = a;
T1 = chebpoly(N,[-1,1],1); T2 = chebpoly(N-2,[-1,1],1); % Chebyshev polynomial of first kind
U1 = chebpoly(N-1,[-1,1],2); U2 = chebpoly(N-3,[-1,1],2); % Chebyshev polynomial of second kind
if m == 1
    d0 = -(f(c)-P(c))/(T1(c)-T2(c));
    b(N-1) = b(N-1)+d0;
    b(N+1) = -d0;
elseif m == 2
    d0 = -1/2*(df(c)-dP(c)-(f(c)-P(c))/(T1(c)-T2(c))*(N*U1(c)-(N-2)*U2(c)))/(T1(c)-T2(c));
    d1 = (df(c)-dP(c)-(f(c)-P(c))/(T1(c)-T2(c))*(N*U1(c)-(N-2)*U2(c)))/(T1(c)-T2(c))*c-(f(c)-P(c))/(T1(c)-T2(c));
    b(N-1) = b(N-1)+d1;
    b(N-2) = b(N-2)+d0;
    b(N+1) = -d1;
    b(N+2) = -d0;
else
    fprintf('have not been done');
end
end

